heic_to_png_jpg library

Classes

HeicConversionTask
Describes a single HEIC conversion job for use with HeicConverter.convertBatch.
HeicConverter
HeicImageInfo
Metadata about a HEIC image extracted without full conversion.

Enums

ImageFormat

Exceptions / Errors

ConversionFailedException
Thrown when conversion fails due to an encoding/decoding error.
HeicConversionException
Base exception for all HEIC conversion errors.
InvalidHeicDataException
Thrown when the input data is not a valid HEIC file.
PlatformNotSupportedException
Thrown when a feature is not supported on the current platform.